@@ -15,9 +15,10 @@
 #' @seealso \code{\link{shr}}, \code{\link{print.shr}},
 #' \code{\link{plot.shr}}
 #' @keywords methods
+#' @return No return value.
 #' @examples
 #' 
-#' \dontrun{
+#' \donttest{
 #' # a penalized survival model 
 #' data(testdata)
 #' library(prodlim)
@@ -41,41 +42,41 @@ summary.shr <- function(object,conf.int=.95,digits=4,pvalDigits=4,eps=.0001, ...
             cat("number of events: ", x$events,"\n")
             cat("number of covariates: ", x$NC,"\n")
             if(length(x$na.action))cat("observation deleted due to missing: ",length(x$na.action),"\n")
-		if((x$NC>0)&&(x$converged[2]==1)){
-			wald <- (x$coef/x$se)**2
-			z <- abs(qnorm((1 + conf.int)/2))
-			out <- data.frame("Hazard ratio"=format(round(exp(x$coef),digits)),
-                                          "Standard error"=format(round(x$se,digits)),
-                                          "CI"=paste("[",format(round(exp(x$coef - z * x$se),2)),";",format(round(exp(x$coef + z * x$se),2)),"]",sep=""),
-                                          "P-value"=format.pval(1 - pchisq(wald, 1),digits=pvalDigits,eps=eps))
-                        names(out)[3] <- paste("CI",round(100*conf.int),sep=".")
-			rownames(out) <- names(x$coef)
-			print(out,row.names=T)
-                    }
-    }
-}else{
-
-    	x <- object
-#	if (x$istop == 1){
-	if (x$converged[1] == 1){
-		cat("Survival model using a Penalized Likelihood on the hazard function.\n")
-		cat("\n")
-		cat("number of subject: ", x$N,"\n")
-		cat("number of covariates: ", x$NC,"\n")
-		if(length(x$na.action))cat("observation deleted due to missing: ",length(x$na.action),"\n")
-
-		if((x$NC>0)&&(x$converged[2]==1)){
-			wald <- (x$coef/x$se)**2
-			z <- abs(qnorm((1 + conf.int)/2))
-			out <- data.frame("Hazard ratio"=format(round(exp(x$coef),digits)),
-                                          "Standard error"=format(round(x$se,digits)),
-                                          "CI"=paste("[",format(round(exp(x$coef - z * x$se),2)),";",format(round(exp(x$coef + z * x$se),2)),"]",sep=""),
-                                          "P-value"=format.pval(1 - pchisq(wald, 1),digits=pvalDigits,eps=eps))
-                        names(out)[3] <- paste("CI",round(100*conf.int),sep=".")
-			rownames(out) <- names(x$coef)
-			print(out,row.names=T)
-                    }
+            if((x$NC>0)&&(x$converged[2]==1)){
+                wald <- (x$coef/x$se)**2
+                z <- abs(qnorm((1 + conf.int)/2))
+                out <- data.frame("Hazard ratio"=format(round(exp(x$coef),digits)),
+                                  "Standard error"=format(round(x$se,digits)),
+                                  "CI"=paste("[",format(round(exp(x$coef - z * x$se),2)),";",format(round(exp(x$coef + z * x$se),2)),"]",sep=""),
+                                  "P-value"=format.pval(1 - pchisq(wald, 1),digits=pvalDigits,eps=eps))
+                names(out)[3] <- paste("CI",round(100*conf.int),sep=".")
+                rownames(out) <- names(x$coef)
+                print(out,row.names=T)
             }
+        }
+    }else{
+    	x <- object
+        #	if (x$istop == 1){
+	if (x$converged[1] == 1){
+            cat("Survival model using a Penalized Likelihood on the hazard function.\n")
+            cat("\n")
+            cat("number of subject: ", x$N,"\n")
+            cat("number of covariates: ", x$NC,"\n")
+            if(length(x$na.action))cat("observation deleted due to missing: ",length(x$na.action),"\n")
+
+            if((x$NC>0)&&(x$converged[2]==1)){
+                wald <- (x$coef/x$se)**2
+                z <- abs(qnorm((1 + conf.int)/2))
+                out <- data.frame("Hazard ratio"=format(round(exp(x$coef),digits)),
+                                  "Standard error"=format(round(x$se,digits)),
+                                  "CI"=paste("[",format(round(exp(x$coef - z * x$se),2)),";",format(round(exp(x$coef + z * x$se),2)),"]",sep=""),
+                                  "P-value"=format.pval(1 - pchisq(wald, 1),digits=pvalDigits,eps=eps))
+                names(out)[3] <- paste("CI",round(100*conf.int),sep=".")
+                rownames(out) <- names(x$coef)
+                print(out,row.names=TRUE)
+            }
+        }
     }
+    return(NULL)
 }
     
